<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/

$enableAppKeyValidation = false;
$defaultUserName = 'admin';
$defaultUserAccessKey = 'iFOdqrI8lS5UhNTa';

$defaultOwner = 'admin';
$successURL = '';
$failureURL = '';

/**
 * JSON or HTML. if incase success and failure URL is NOT specified.
 */
$defaultSuccessAction = 'HTML';

$defaultSuccessMessage = 'LBL_SUCCESS';

?>